@@ -724,6 +724,8 @@ void eatCFWS(const char *&scursor, const char *const send, bool isCRLF)
         case '\t': // whitespace
         case '\r':
         case '\n': // folding
+        case '\f': // things that shouldn't occure but we need to match isspace()
+        case '\v':
             continue;
 
         case '(': // comment
@@ -1685,7 +1687,6 @@ static bool parseAlphaNumericTimeZone(const char *&scursor,
     }
     for (int i = 0 ; i < timeZonesLen ; ++i) {
         if (maybeTimeZone.compare(timeZones[i].tzName, Qt::CaseInsensitive) == 0) {
-            scursor += maybeTimeZone.size();
             secsEastOfGMT = timeZones[i].secsEastOfGMT;
             timeZoneKnown = true;
 
@@ -1705,14 +1706,19 @@ static bool parseAlphaNumericTimeZone(const char *&scursor,
 }
 
 // parse a number and return the number of digits parsed:
-int parseDigits(const char *&scursor, const char *const send, int &result)
+int parseDigits(const char *&scursor, const char *const send, int &finalResult)
 {
-    result = 0;
+    int64_t result = 0;
+    finalResult = 0;
     int digits = 0;
     for (; scursor != send && isdigit(*scursor) ; scursor++, digits++) {
         result *= 10;
         result += int(*scursor - '0');
+        if (result > std::numeric_limits<int>::max()) {
+            return 0;
+        }
     }
+    finalResult = result;
     return digits;
 }
 
@@ -1748,6 +1754,7 @@ static bool parseTimeOfDay(const char *&scursor, const char *const send,
 
     eatCFWS(scursor, send, isCRLF);
     if (scursor == send) {
+        sec = 0;
         return true; // seconds are optional
     }
 
